@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -20,7 +20,7 @@
 #include "smtpmailtransportplugin.h"
 #include "smtpconfigdialog.h"
 #include "smtpjob.h"
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 #include <KLocalizedString>
 
 K_PLUGIN_CLASS_WITH_JSON(SMTPMailTransportPlugin, "smtpmailtransport.json")
@@ -50,7 +50,7 @@ bool SMTPMailTransportPlugin::configureTransport(const QString &identifier, Mail
     Q_UNUSED(identifier);
     QPointer<MailTransport::SmtpConfigDialog> transportConfigDialog
         = new MailTransport::SmtpConfigDialog(transport, parent);
-    transportConfigDialog->setWindowTitle(i18n("Configure account"));
+    transportConfigDialog->setWindowTitle(i18nc("@title:window", "Configure account"));
     bool okClicked = (transportConfigDialog->exec() == QDialog::Accepted);
     delete transportConfigDialog;
     return okClicked;
